.. py:currentmodule:: rubin_scheduler.scheduler

.. _fbs-api-example-scheduler:


Example Scheduler
^^^^^^^^^^^^^^^^^

.. automodule:: rubin_scheduler.scheduler.example.example_scheduler
    :imported-members:
    :members:
    :show-inheritance:
